@@ -16,12 +16,12 @@ impl<const W: usize, const N: usize, const NP1: usize, const BLOCK: u32> Logic
 {
     #[hdl_gen]
     fn update(&mut self) {
-        self.bus.link(&mut self.port.bus);
+        SoCPortResponder::<W>::link(&mut self.bus, &mut self.port.bus);
         self.fifo.clock.next = self.bus.clock.val();
         self.fifo.bus_write.data.next = self.port.port_out.val();
         self.fifo.bus_write.write.next = self.port.strobe_out.val();
         self.port.ready.next = !self.fifo.bus_write.full.val();
-        self.fifo_bus.link(&mut self.fifo.bus_read);
+        FIFOReadResponder::<Bits<W>>::link(&mut self.fifo_bus, &mut self.fifo.bus_read);
     }
 }
 
